diff --git a/CHANGELOG.md b/CHANGELOG.md
index 734f772bab3..f9829dcb85f 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -11,6 +11,21 @@ and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0
### Changed
+## [5.66.0] - 2023-07-28
+
+### Added
+
+- Added TeamsAppSettings model and requests.
+- Several Evidence models added to the Security namespace. This includes but is not limited to:
+- BlobEvidence.
+- ContainerEvidence.
+- ContainerRegistryEvidence.
+- KubernetesClusterEvidence.
+- ContainerPortProtocol model.
+- Dictionary model.
+- FileHashAlgorithm model.
+- FileHash model.
+
## [5.65.0] - 2023-07-20
### Added
diff --git a/README.md b/README.md
index 1dcf621b87a..81fbcfcf8a3 100644
--- a/README.md
+++ b/README.md
@@ -19,7 +19,7 @@ repositories {
dependencies {
// Include the sdk as a dependency
- implementation 'com.microsoft.graph:microsoft-graph:5.65.0'
+ implementation 'com.microsoft.graph:microsoft-graph:5.66.0'
// Uncomment the line below if you are building an android application
//implementation 'com.google.guava:guava:30.1.1-android'
// This dependency is only needed if you are using the TokenCrendentialAuthProvider
@@ -36,7 +36,7 @@ Add the dependency in `dependencies` in pom.xml
com.microsoft.graph
microsoft-graph
- 5.65.0
+ 5.66.0
@@ -196,5 +196,6 @@ Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the [MI
+
diff --git a/gradle.properties b/gradle.properties
index 8ffa94e2172..8428a82011c 100644
--- a/gradle.properties
+++ b/gradle.properties
@@ -26,7 +26,7 @@ org.gradle.caching=true
mavenGroupId = com.microsoft.graph
mavenArtifactId = microsoft-graph
mavenMajorVersion = 5
-mavenMinorVersion = 65
+mavenMinorVersion = 66
mavenPatchVersion = 0
mavenArtifactSuffix =
@@ -119,5 +119,6 @@ mavenCentralPublishingEnabled=false
+
diff --git a/src/main/java/com/microsoft/graph/info/Constants.java b/src/main/java/com/microsoft/graph/info/Constants.java
index 3f07379b860..6aa64e5b580 100644
--- a/src/main/java/com/microsoft/graph/info/Constants.java
+++ b/src/main/java/com/microsoft/graph/info/Constants.java
@@ -18,7 +18,7 @@ private Constants() {
/** The client secret to use for unit testing */
public static final String CLIENTSECRET = "clientsecret";
/** The SDK version */
- public static final String VERSION_NAME = "5.65.0";
+ public static final String VERSION_NAME = "5.66.0";
}
@@ -96,5 +96,6 @@ private Constants() {
+
diff --git a/src/main/java/com/microsoft/graph/models/ApiApplication.java b/src/main/java/com/microsoft/graph/models/ApiApplication.java
index b24b639bee4..12c2ecfe14c 100644
--- a/src/main/java/com/microsoft/graph/models/ApiApplication.java
+++ b/src/main/java/com/microsoft/graph/models/ApiApplication.java
@@ -78,7 +78,7 @@ public final AdditionalDataManager additionalDataManager() {
/**
* The Requested Access Token Version.
- * Specifies the access token version expected by this resource. This changes the version and format of the JWT produced independent of the endpoint or client used to request the access token. The endpoint used, v1.0 or v2.0, is chosen by the client and only impacts the version of id_tokens. Resources need to explicitly configure requestedAccessTokenVersion to indicate the supported access token format. Possible values for requestedAccessTokenVersion are 1, 2, or null. If the value is null, this defaults to 1, which corresponds to the v1.0 endpoint. If signInAudience on the application is configured as AzureADandPersonalMicrosoftAccount, the value for this property must be 2
+ * Specifies the access token version expected by this resource. This changes the version and format of the JWT produced independent of the endpoint or client used to request the access token. The endpoint used, v1.0 or v2.0, is chosen by the client and only impacts the version of id_tokens. Resources need to explicitly configure requestedAccessTokenVersion to indicate the supported access token format. Possible values for requestedAccessTokenVersion are 1, 2, or null. If the value is null, this defaults to 1, which corresponds to the v1.0 endpoint. If signInAudience on the application is configured as AzureADandPersonalMicrosoftAccount or PersonalMicrosoftAccount, the value for this property must be 2.
*/
@SerializedName(value = "requestedAccessTokenVersion", alternate = {"RequestedAccessTokenVersion"})
@Expose
diff --git a/src/main/java/com/microsoft/graph/models/ConditionalAccessApplications.java b/src/main/java/com/microsoft/graph/models/ConditionalAccessApplications.java
index 1cea31544e1..058f2ea5406 100644
--- a/src/main/java/com/microsoft/graph/models/ConditionalAccessApplications.java
+++ b/src/main/java/com/microsoft/graph/models/ConditionalAccessApplications.java
@@ -9,6 +9,7 @@
import com.microsoft.graph.serializer.AdditionalDataManager;
import java.util.EnumSet;
import com.microsoft.graph.http.BaseCollectionPage;
+import com.microsoft.graph.models.ConditionalAccessFilter;
import com.google.gson.JsonObject;
@@ -38,6 +39,15 @@ public final AdditionalDataManager additionalDataManager() {
return additionalDataManager;
}
+ /**
+ * The Application Filter.
+ *
+ */
+ @SerializedName(value = "applicationFilter", alternate = {"ApplicationFilter"})
+ @Expose
+ @Nullable
+ public ConditionalAccessFilter applicationFilter;
+
/**
* The Exclude Applications.
* Can be one of the following: The list of client IDs (appId) explicitly excluded from the policy. Office365 - For the list of apps included in Office365, see Conditional Access target apps: Office 365
diff --git a/src/main/java/com/microsoft/graph/models/ConditionalAccessClientApplications.java b/src/main/java/com/microsoft/graph/models/ConditionalAccessClientApplications.java
index 55cb4317886..31487474616 100644
--- a/src/main/java/com/microsoft/graph/models/ConditionalAccessClientApplications.java
+++ b/src/main/java/com/microsoft/graph/models/ConditionalAccessClientApplications.java
@@ -9,6 +9,7 @@
import com.microsoft.graph.serializer.AdditionalDataManager;
import java.util.EnumSet;
import com.microsoft.graph.http.BaseCollectionPage;
+import com.microsoft.graph.models.ConditionalAccessFilter;
import com.google.gson.JsonObject;
@@ -56,6 +57,15 @@ public final AdditionalDataManager additionalDataManager() {
@Nullable
public java.util.List includeServicePrincipals;
+ /**
+ * The Service Principal Filter.
+ *
+ */
+ @SerializedName(value = "servicePrincipalFilter", alternate = {"ServicePrincipalFilter"})
+ @Expose
+ @Nullable
+ public ConditionalAccessFilter servicePrincipalFilter;
+
/**
* Sets the raw JSON object
diff --git a/src/main/java/com/microsoft/graph/models/LicenseUnitsDetail.java b/src/main/java/com/microsoft/graph/models/LicenseUnitsDetail.java
index 1df2bee1edd..7fed34d3bbe 100644
--- a/src/main/java/com/microsoft/graph/models/LicenseUnitsDetail.java
+++ b/src/main/java/com/microsoft/graph/models/LicenseUnitsDetail.java
@@ -48,7 +48,7 @@ public final AdditionalDataManager additionalDataManager() {
/**
* The Locked Out.
- *
+ * The number of units that are locked out because the customer cancelled their subscription of the service SKU.
*/
@SerializedName(value = "lockedOut", alternate = {"LockedOut"})
@Expose
diff --git a/src/main/java/com/microsoft/graph/models/SubscribedSku.java b/src/main/java/com/microsoft/graph/models/SubscribedSku.java
index 1b4b92f28d0..b9e86a50461 100644
--- a/src/main/java/com/microsoft/graph/models/SubscribedSku.java
+++ b/src/main/java/com/microsoft/graph/models/SubscribedSku.java
@@ -30,7 +30,7 @@ public class SubscribedSku extends Entity implements IJsonBackedObject {
/**
* The Account Id.
- *
+ * The unique ID of the account this SKU belongs to.
*/
@SerializedName(value = "accountId", alternate = {"AccountId"})
@Expose
@@ -39,7 +39,7 @@ public class SubscribedSku extends Entity implements IJsonBackedObject {
/**
* The Account Name.
- *
+ * The name of the account this SKU belongs to.
*/
@SerializedName(value = "accountName", alternate = {"AccountName"})
@Expose
@@ -48,7 +48,7 @@ public class SubscribedSku extends Entity implements IJsonBackedObject {
/**
* The Applies To.
- * For example, 'User' or 'Company'.
+ * The target class for this SKU. Only SKUs with target class User are assignable. Possible values are: 'User', 'Company'.
*/
@SerializedName(value = "appliesTo", alternate = {"AppliesTo"})
@Expose
@@ -57,7 +57,7 @@ public class SubscribedSku extends Entity implements IJsonBackedObject {
/**
* The Capability Status.
- * Possible values are: Enabled, Warning, Suspended, Deleted, LockedOut. The capabilityStatus is Enabled if the prepaidUnits property has at least 1 unit that is enabled, and LockedOut if the customer cancelled their subscription.
+ * Enabled indicates that the prepaidUnits property has at least one unit that is enabled. LockedOut indicates that the customer cancelled their subscription. Possible values are: Enabled, Warning, Suspended, Deleted, LockedOut.
*/
@SerializedName(value = "capabilityStatus", alternate = {"CapabilityStatus"})
@Expose
@@ -84,7 +84,7 @@ public class SubscribedSku extends Entity implements IJsonBackedObject {
/**
* The Service Plans.
- * Information about the service plans that are available with the SKU. Not nullable
+ * Information about the service plans that are available with the SKU. Not nullable.
*/
@SerializedName(value = "servicePlans", alternate = {"ServicePlans"})
@Expose
diff --git a/src/main/java/com/microsoft/graph/models/TeamsAppSettings.java b/src/main/java/com/microsoft/graph/models/TeamsAppSettings.java
new file mode 100644
index 00000000000..62831ca8fe8
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/models/TeamsAppSettings.java
@@ -0,0 +1,47 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.models.Entity;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Teams App Settings.
+ */
+public class TeamsAppSettings extends Entity implements IJsonBackedObject {
+
+
+ /**
+ * The Allow User Requests For App Access.
+ *
+ */
+ @SerializedName(value = "allowUserRequestsForAppAccess", alternate = {"AllowUserRequestsForAppAccess"})
+ @Expose
+ @Nullable
+ public Boolean allowUserRequestsForAppAccess;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/models/Teamwork.java b/src/main/java/com/microsoft/graph/models/Teamwork.java
index 78713b127d2..7ddea04f7b1 100644
--- a/src/main/java/com/microsoft/graph/models/Teamwork.java
+++ b/src/main/java/com/microsoft/graph/models/Teamwork.java
@@ -9,6 +9,7 @@
import com.microsoft.graph.serializer.AdditionalDataManager;
import java.util.EnumSet;
import com.microsoft.graph.http.BaseCollectionPage;
+import com.microsoft.graph.models.TeamsAppSettings;
import com.microsoft.graph.models.Entity;
import com.microsoft.graph.requests.WorkforceIntegrationCollectionPage;
import com.microsoft.graph.requests.DeletedTeamCollectionPage;
@@ -46,6 +47,15 @@ public class Teamwork extends Entity implements IJsonBackedObject {
@Nullable
public com.microsoft.graph.requests.DeletedTeamCollectionPage deletedTeams;
+ /**
+ * The Teams App Settings.
+ *
+ */
+ @SerializedName(value = "teamsAppSettings", alternate = {"TeamsAppSettings"})
+ @Expose
+ @Nullable
+ public TeamsAppSettings teamsAppSettings;
+
/**
* Sets the raw JSON object
diff --git a/src/main/java/com/microsoft/graph/requests/GraphServiceClient.java b/src/main/java/com/microsoft/graph/requests/GraphServiceClient.java
index 0bf21b87307..c3fbdf01b24 100644
--- a/src/main/java/com/microsoft/graph/requests/GraphServiceClient.java
+++ b/src/main/java/com/microsoft/graph/requests/GraphServiceClient.java
@@ -536,27 +536,6 @@ public com.microsoft.graph.requests.GroupSettingTemplateRequestBuilder groupSett
return new com.microsoft.graph.requests.GroupSettingTemplateRequestBuilder(getServiceRoot() + "/groupSettingTemplates/" + id, this, null);
}
- /**
- * Gets the collection of Localizations objects
- *
- * @return the request builder for the collection of Localizations objects
- */
- @Nonnull
- public com.microsoft.graph.requests.OrganizationalBrandingLocalizationCollectionRequestBuilder localizations() {
- return new com.microsoft.graph.requests.OrganizationalBrandingLocalizationCollectionRequestBuilder(getServiceRoot() + "/localizations", this, null);
- }
-
- /**
- * Gets a single Localizations
- *
- * @param id the id of the Localizations to retrieve
- * @return the request builder for the Localizations object
- */
- @Nonnull
- public com.microsoft.graph.requests.OrganizationalBrandingLocalizationRequestBuilder localizations(@Nonnull final String id) {
- return new com.microsoft.graph.requests.OrganizationalBrandingLocalizationRequestBuilder(getServiceRoot() + "/localizations/" + id, this, null);
- }
-
/**
* Gets the collection of Oauth2PermissionGrants objects
*
diff --git a/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequest.java b/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequest.java
index 21da5e2a3f2..97bbce76ad0 100644
--- a/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequest.java
+++ b/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequest.java
@@ -7,6 +7,7 @@
import com.microsoft.graph.http.IRequestBuilder;
import com.microsoft.graph.core.ClientException;
+import com.microsoft.graph.models.OrganizationalBranding;
import com.microsoft.graph.models.OrganizationalBrandingLocalization;
import java.util.Arrays;
import java.util.EnumSet;
diff --git a/src/main/java/com/microsoft/graph/requests/TeamsAppSettingsRequest.java b/src/main/java/com/microsoft/graph/requests/TeamsAppSettingsRequest.java
new file mode 100644
index 00000000000..96a85e35d4f
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/requests/TeamsAppSettingsRequest.java
@@ -0,0 +1,173 @@
+// Template Source: BaseEntityRequest.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.requests;
+
+import com.microsoft.graph.http.IRequestBuilder;
+import com.microsoft.graph.core.ClientException;
+import com.microsoft.graph.models.TeamsAppSettings;
+import java.util.Arrays;
+import java.util.EnumSet;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+import com.microsoft.graph.core.IBaseClient;
+import com.microsoft.graph.http.BaseRequest;
+import com.microsoft.graph.http.HttpMethod;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Teams App Settings Request.
+ */
+public class TeamsAppSettingsRequest extends BaseRequest {
+
+ /**
+ * The request for the TeamsAppSettings
+ *
+ * @param requestUrl the request URL
+ * @param client the service client
+ * @param requestOptions the options for this request
+ */
+ public TeamsAppSettingsRequest(@Nonnull final String requestUrl, @Nonnull final IBaseClient> client, @Nullable final java.util.List extends com.microsoft.graph.options.Option> requestOptions) {
+ super(requestUrl, client, requestOptions, TeamsAppSettings.class);
+ }
+
+ /**
+ * Gets the TeamsAppSettings from the service
+ *
+ * @return a future with the result
+ */
+ @Nonnull
+ public java.util.concurrent.CompletableFuture getAsync() {
+ return sendAsync(HttpMethod.GET, null);
+ }
+
+ /**
+ * Gets the TeamsAppSettings from the service
+ *
+ * @return the TeamsAppSettings from the request
+ * @throws ClientException this exception occurs if the request was unable to complete for any reason
+ */
+ @Nullable
+ public TeamsAppSettings get() throws ClientException {
+ return send(HttpMethod.GET, null);
+ }
+
+ /**
+ * Delete this item from the service
+ *
+ * @return a future with the deletion result
+ */
+ @Nonnull
+ public java.util.concurrent.CompletableFuture deleteAsync() {
+ return sendAsync(HttpMethod.DELETE, null);
+ }
+
+ /**
+ * Delete this item from the service
+ * @return the resulting response if the service returns anything on deletion
+ *
+ * @throws ClientException if there was an exception during the delete operation
+ */
+ @Nullable
+ public TeamsAppSettings delete() throws ClientException {
+ return send(HttpMethod.DELETE, null);
+ }
+
+ /**
+ * Patches this TeamsAppSettings with a source
+ *
+ * @param sourceTeamsAppSettings the source object with updates
+ * @return a future with the result
+ */
+ @Nonnull
+ public java.util.concurrent.CompletableFuture patchAsync(@Nonnull final TeamsAppSettings sourceTeamsAppSettings) {
+ return sendAsync(HttpMethod.PATCH, sourceTeamsAppSettings);
+ }
+
+ /**
+ * Patches this TeamsAppSettings with a source
+ *
+ * @param sourceTeamsAppSettings the source object with updates
+ * @return the updated TeamsAppSettings
+ * @throws ClientException this exception occurs if the request was unable to complete for any reason
+ */
+ @Nullable
+ public TeamsAppSettings patch(@Nonnull final TeamsAppSettings sourceTeamsAppSettings) throws ClientException {
+ return send(HttpMethod.PATCH, sourceTeamsAppSettings);
+ }
+
+ /**
+ * Creates a TeamsAppSettings with a new object
+ *
+ * @param newTeamsAppSettings the new object to create
+ * @return a future with the result
+ */
+ @Nonnull
+ public java.util.concurrent.CompletableFuture postAsync(@Nonnull final TeamsAppSettings newTeamsAppSettings) {
+ return sendAsync(HttpMethod.POST, newTeamsAppSettings);
+ }
+
+ /**
+ * Creates a TeamsAppSettings with a new object
+ *
+ * @param newTeamsAppSettings the new object to create
+ * @return the created TeamsAppSettings
+ * @throws ClientException this exception occurs if the request was unable to complete for any reason
+ */
+ @Nullable
+ public TeamsAppSettings post(@Nonnull final TeamsAppSettings newTeamsAppSettings) throws ClientException {
+ return send(HttpMethod.POST, newTeamsAppSettings);
+ }
+
+ /**
+ * Creates a TeamsAppSettings with a new object
+ *
+ * @param newTeamsAppSettings the object to create/update
+ * @return a future with the result
+ */
+ @Nonnull
+ public java.util.concurrent.CompletableFuture putAsync(@Nonnull final TeamsAppSettings newTeamsAppSettings) {
+ return sendAsync(HttpMethod.PUT, newTeamsAppSettings);
+ }
+
+ /**
+ * Creates a TeamsAppSettings with a new object
+ *
+ * @param newTeamsAppSettings the object to create/update
+ * @return the created TeamsAppSettings
+ * @throws ClientException this exception occurs if the request was unable to complete for any reason
+ */
+ @Nullable
+ public TeamsAppSettings put(@Nonnull final TeamsAppSettings newTeamsAppSettings) throws ClientException {
+ return send(HttpMethod.PUT, newTeamsAppSettings);
+ }
+
+ /**
+ * Sets the select clause for the request
+ *
+ * @param value the select clause
+ * @return the updated request
+ */
+ @Nonnull
+ public TeamsAppSettingsRequest select(@Nonnull final String value) {
+ addSelectOption(value);
+ return this;
+ }
+
+ /**
+ * Sets the expand clause for the request
+ *
+ * @param value the expand clause
+ * @return the updated request
+ */
+ @Nonnull
+ public TeamsAppSettingsRequest expand(@Nonnull final String value) {
+ addExpandOption(value);
+ return this;
+ }
+
+}
+
diff --git a/src/main/java/com/microsoft/graph/requests/TeamsAppSettingsRequestBuilder.java b/src/main/java/com/microsoft/graph/requests/TeamsAppSettingsRequestBuilder.java
new file mode 100644
index 00000000000..6107ef552ce
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/requests/TeamsAppSettingsRequestBuilder.java
@@ -0,0 +1,59 @@
+// Template Source: BaseEntityRequestBuilder.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.requests;
+
+import com.microsoft.graph.http.IRequestBuilder;
+import com.microsoft.graph.core.ClientException;
+import com.microsoft.graph.models.TeamsAppSettings;
+import java.util.Arrays;
+import java.util.EnumSet;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+import com.microsoft.graph.core.IBaseClient;
+import com.microsoft.graph.http.BaseRequestBuilder;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Teams App Settings Request Builder.
+ */
+public class TeamsAppSettingsRequestBuilder extends BaseRequestBuilder {
+
+ /**
+ * The request builder for the TeamsAppSettings
+ *
+ * @param requestUrl the request URL
+ * @param client the service client
+ * @param requestOptions the options for this request
+ */
+ public TeamsAppSettingsRequestBuilder(@Nonnull final String requestUrl, @Nonnull final IBaseClient> client, @Nullable final java.util.List extends com.microsoft.graph.options.Option> requestOptions) {
+ super(requestUrl, client, requestOptions);
+ }
+
+ /**
+ * Creates the request
+ *
+ * @param requestOptions the options for this request
+ * @return the TeamsAppSettingsRequest instance
+ */
+ @Nonnull
+ public TeamsAppSettingsRequest buildRequest(@Nullable final com.microsoft.graph.options.Option... requestOptions) {
+ return buildRequest(getOptions(requestOptions));
+ }
+
+ /**
+ * Creates the request with specific requestOptions instead of the existing requestOptions
+ *
+ * @param requestOptions the options for this request
+ * @return the TeamsAppSettingsRequest instance
+ */
+ @Nonnull
+ public TeamsAppSettingsRequest buildRequest(@Nonnull final java.util.List extends com.microsoft.graph.options.Option> requestOptions) {
+ return new com.microsoft.graph.requests.TeamsAppSettingsRequest(getRequestUrl(), getClient(), requestOptions);
+ }
+
+
+}
diff --git a/src/main/java/com/microsoft/graph/requests/TeamworkRequestBuilder.java b/src/main/java/com/microsoft/graph/requests/TeamworkRequestBuilder.java
index bd145373e69..b2c8b9ee69b 100644
--- a/src/main/java/com/microsoft/graph/requests/TeamworkRequestBuilder.java
+++ b/src/main/java/com/microsoft/graph/requests/TeamworkRequestBuilder.java
@@ -102,6 +102,16 @@ public com.microsoft.graph.requests.DeletedTeamRequestBuilder deletedTeams(@Nonn
return new com.microsoft.graph.requests.DeletedTeamRequestBuilder(getRequestUrlWithAdditionalSegment("deletedTeams") + "/" + id, getClient(), null);
}
+ /**
+ * Gets the request builder for TeamsAppSettings
+ *
+ * @return the TeamsAppSettingsRequestBuilder instance
+ */
+ @Nonnull
+ public com.microsoft.graph.requests.TeamsAppSettingsRequestBuilder teamsAppSettings() {
+ return new com.microsoft.graph.requests.TeamsAppSettingsRequestBuilder(getRequestUrlWithAdditionalSegment("teamsAppSettings"), getClient(), null);
+ }
+
/**
* Gets a builder to execute the method
* @return the request builder
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/BlobContainerEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/BlobContainerEvidence.java
new file mode 100644
index 00000000000..f75eefdc1f6
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/BlobContainerEvidence.java
@@ -0,0 +1,66 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.AzureResourceEvidence;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Blob Container Evidence.
+ */
+public class BlobContainerEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Storage Resource.
+ *
+ */
+ @SerializedName(value = "storageResource", alternate = {"StorageResource"})
+ @Expose
+ @Nullable
+ public AzureResourceEvidence storageResource;
+
+ /**
+ * The Url.
+ *
+ */
+ @SerializedName(value = "url", alternate = {"Url"})
+ @Expose
+ @Nullable
+ public String url;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/BlobEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/BlobEvidence.java
new file mode 100644
index 00000000000..7e15617c115
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/BlobEvidence.java
@@ -0,0 +1,86 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.http.BaseCollectionPage;
+import com.microsoft.graph.security.models.BlobContainerEvidence;
+import com.microsoft.graph.security.models.FileHash;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Blob Evidence.
+ */
+public class BlobEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Blob Container.
+ *
+ */
+ @SerializedName(value = "blobContainer", alternate = {"BlobContainer"})
+ @Expose
+ @Nullable
+ public BlobContainerEvidence blobContainer;
+
+ /**
+ * The Etag.
+ *
+ */
+ @SerializedName(value = "etag", alternate = {"Etag"})
+ @Expose
+ @Nullable
+ public String etag;
+
+ /**
+ * The File Hashes.
+ *
+ */
+ @SerializedName(value = "fileHashes", alternate = {"FileHashes"})
+ @Expose
+ @Nullable
+ public java.util.List fileHashes;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Url.
+ *
+ */
+ @SerializedName(value = "url", alternate = {"Url"})
+ @Expose
+ @Nullable
+ public String url;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerEvidence.java
new file mode 100644
index 00000000000..e88ba8757e4
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerEvidence.java
@@ -0,0 +1,104 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.http.BaseCollectionPage;
+import com.microsoft.graph.security.models.ContainerImageEvidence;
+import com.microsoft.graph.security.models.KubernetesPodEvidence;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Container Evidence.
+ */
+public class ContainerEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Args.
+ *
+ */
+ @SerializedName(value = "args", alternate = {"Args"})
+ @Expose
+ @Nullable
+ public java.util.List args;
+
+ /**
+ * The Command.
+ *
+ */
+ @SerializedName(value = "command", alternate = {"Command"})
+ @Expose
+ @Nullable
+ public java.util.List command;
+
+ /**
+ * The Container Id.
+ *
+ */
+ @SerializedName(value = "containerId", alternate = {"ContainerId"})
+ @Expose
+ @Nullable
+ public String containerId;
+
+ /**
+ * The Image.
+ *
+ */
+ @SerializedName(value = "image", alternate = {"Image"})
+ @Expose
+ @Nullable
+ public ContainerImageEvidence image;
+
+ /**
+ * The Is Privileged.
+ *
+ */
+ @SerializedName(value = "isPrivileged", alternate = {"IsPrivileged"})
+ @Expose
+ @Nullable
+ public Boolean isPrivileged;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Pod.
+ *
+ */
+ @SerializedName(value = "pod", alternate = {"Pod"})
+ @Expose
+ @Nullable
+ public KubernetesPodEvidence pod;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerImageEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerImageEvidence.java
new file mode 100644
index 00000000000..fe2d623fbb7
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerImageEvidence.java
@@ -0,0 +1,67 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.ContainerImageEvidence;
+import com.microsoft.graph.security.models.ContainerRegistryEvidence;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Container Image Evidence.
+ */
+public class ContainerImageEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Digest Image.
+ *
+ */
+ @SerializedName(value = "digestImage", alternate = {"DigestImage"})
+ @Expose
+ @Nullable
+ public ContainerImageEvidence digestImage;
+
+ /**
+ * The Image Id.
+ *
+ */
+ @SerializedName(value = "imageId", alternate = {"ImageId"})
+ @Expose
+ @Nullable
+ public String imageId;
+
+ /**
+ * The Registry.
+ *
+ */
+ @SerializedName(value = "registry", alternate = {"Registry"})
+ @Expose
+ @Nullable
+ public ContainerRegistryEvidence registry;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerPortProtocol.java b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerPortProtocol.java
new file mode 100644
index 00000000000..085e154d17b
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerPortProtocol.java
@@ -0,0 +1,34 @@
+// Template Source: Enum.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+
+
+/**
+ * The Enum Container Port Protocol.
+*/
+public enum ContainerPortProtocol
+{
+ /**
+ * udp
+ */
+ UDP,
+ /**
+ * tcp
+ */
+ TCP,
+ /**
+ * sctp
+ */
+ SCTP,
+ /**
+ * unknown Future Value
+ */
+ UNKNOWN_FUTURE_VALUE,
+ /**
+ * For ContainerPortProtocol values that were not expected from the service
+ */
+ UNEXPECTED_VALUE
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerRegistryEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerRegistryEvidence.java
new file mode 100644
index 00000000000..46098dc5968
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/ContainerRegistryEvidence.java
@@ -0,0 +1,47 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Container Registry Evidence.
+ */
+public class ContainerRegistryEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Registry.
+ *
+ */
+ @SerializedName(value = "registry", alternate = {"Registry"})
+ @Expose
+ @Nullable
+ public String registry;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/Dictionary.java b/src/main/java/com/microsoft/graph/securitynamespace/models/Dictionary.java
new file mode 100644
index 00000000000..be9f657b03f
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/Dictionary.java
@@ -0,0 +1,51 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+import java.util.HashMap;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Dictionary.
+ */
+public class Dictionary implements IJsonBackedObject {
+
+ /** the OData type of the object as returned by the service */
+ @SerializedName("@odata.type")
+ @Expose
+ @Nullable
+ public String oDataType;
+
+ private transient AdditionalDataManager additionalDataManager = new AdditionalDataManager(this);
+
+ @Override
+ @Nonnull
+ public final AdditionalDataManager additionalDataManager() {
+ return additionalDataManager;
+ }
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/FileHash.java b/src/main/java/com/microsoft/graph/securitynamespace/models/FileHash.java
new file mode 100644
index 00000000000..0e6ab991863
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/FileHash.java
@@ -0,0 +1,69 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.FileHashAlgorithm;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the File Hash.
+ */
+public class FileHash implements IJsonBackedObject {
+
+ /** the OData type of the object as returned by the service */
+ @SerializedName("@odata.type")
+ @Expose
+ @Nullable
+ public String oDataType;
+
+ private transient AdditionalDataManager additionalDataManager = new AdditionalDataManager(this);
+
+ @Override
+ @Nonnull
+ public final AdditionalDataManager additionalDataManager() {
+ return additionalDataManager;
+ }
+
+ /**
+ * The Algorithm.
+ *
+ */
+ @SerializedName(value = "algorithm", alternate = {"Algorithm"})
+ @Expose
+ @Nullable
+ public FileHashAlgorithm algorithm;
+
+ /**
+ * The Value.
+ *
+ */
+ @SerializedName(value = "value", alternate = {"Value"})
+ @Expose
+ @Nullable
+ public String value;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/FileHashAlgorithm.java b/src/main/java/com/microsoft/graph/securitynamespace/models/FileHashAlgorithm.java
new file mode 100644
index 00000000000..93d966c7662
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/FileHashAlgorithm.java
@@ -0,0 +1,42 @@
+// Template Source: Enum.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+
+
+/**
+ * The Enum File Hash Algorithm.
+*/
+public enum FileHashAlgorithm
+{
+ /**
+ * unknown
+ */
+ UNKNOWN,
+ /**
+ * md5
+ */
+ MD5,
+ /**
+ * sha1
+ */
+ SHA1,
+ /**
+ * sha256
+ */
+ SHA256,
+ /**
+ * sha256ac
+ */
+ SHA256AC,
+ /**
+ * unknown Future Value
+ */
+ UNKNOWN_FUTURE_VALUE,
+ /**
+ * For FileHashAlgorithm values that were not expected from the service
+ */
+ UNEXPECTED_VALUE
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesClusterEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesClusterEvidence.java
new file mode 100644
index 00000000000..f6a10a99e20
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesClusterEvidence.java
@@ -0,0 +1,84 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.AlertEvidence;
+import com.microsoft.graph.security.models.KubernetesPlatform;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Cluster Evidence.
+ */
+public class KubernetesClusterEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Cloud Resource.
+ *
+ */
+ @SerializedName(value = "cloudResource", alternate = {"CloudResource"})
+ @Expose
+ @Nullable
+ public AlertEvidence cloudResource;
+
+ /**
+ * The Distribution.
+ *
+ */
+ @SerializedName(value = "distribution", alternate = {"Distribution"})
+ @Expose
+ @Nullable
+ public String distribution;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Platform.
+ *
+ */
+ @SerializedName(value = "platform", alternate = {"Platform"})
+ @Expose
+ @Nullable
+ public KubernetesPlatform platform;
+
+ /**
+ * The Version.
+ *
+ */
+ @SerializedName(value = "version", alternate = {"Version"})
+ @Expose
+ @Nullable
+ public String version;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesControllerEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesControllerEvidence.java
new file mode 100644
index 00000000000..cecb8b31dae
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesControllerEvidence.java
@@ -0,0 +1,76 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.Dictionary;
+import com.microsoft.graph.security.models.KubernetesNamespaceEvidence;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Controller Evidence.
+ */
+public class KubernetesControllerEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Labels.
+ *
+ */
+ @SerializedName(value = "labels", alternate = {"Labels"})
+ @Expose
+ @Nullable
+ public Dictionary labels;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Namespace.
+ *
+ */
+ @SerializedName(value = "namespace", alternate = {"Namespace"})
+ @Expose
+ @Nullable
+ public KubernetesNamespaceEvidence namespace;
+
+ /**
+ * The Type.
+ *
+ */
+ @SerializedName(value = "type", alternate = {"Type"})
+ @Expose
+ @Nullable
+ public String type;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesNamespaceEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesNamespaceEvidence.java
new file mode 100644
index 00000000000..a112125cbc9
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesNamespaceEvidence.java
@@ -0,0 +1,67 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.KubernetesClusterEvidence;
+import com.microsoft.graph.security.models.Dictionary;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Namespace Evidence.
+ */
+public class KubernetesNamespaceEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Cluster.
+ *
+ */
+ @SerializedName(value = "cluster", alternate = {"Cluster"})
+ @Expose
+ @Nullable
+ public KubernetesClusterEvidence cluster;
+
+ /**
+ * The Labels.
+ *
+ */
+ @SerializedName(value = "labels", alternate = {"Labels"})
+ @Expose
+ @Nullable
+ public Dictionary labels;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesPlatform.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesPlatform.java
new file mode 100644
index 00000000000..7546f8e4a9c
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesPlatform.java
@@ -0,0 +1,42 @@
+// Template Source: Enum.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+
+
+/**
+ * The Enum Kubernetes Platform.
+*/
+public enum KubernetesPlatform
+{
+ /**
+ * unknown
+ */
+ UNKNOWN,
+ /**
+ * aks
+ */
+ AKS,
+ /**
+ * eks
+ */
+ EKS,
+ /**
+ * gke
+ */
+ GKE,
+ /**
+ * arc
+ */
+ ARC,
+ /**
+ * unknown Future Value
+ */
+ UNKNOWN_FUTURE_VALUE,
+ /**
+ * For KubernetesPlatform values that were not expected from the service
+ */
+ UNEXPECTED_VALUE
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesPodEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesPodEvidence.java
new file mode 100644
index 00000000000..877253c0959
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesPodEvidence.java
@@ -0,0 +1,126 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.http.BaseCollectionPage;
+import com.microsoft.graph.security.models.ContainerEvidence;
+import com.microsoft.graph.security.models.KubernetesControllerEvidence;
+import com.microsoft.graph.security.models.Dictionary;
+import com.microsoft.graph.security.models.KubernetesNamespaceEvidence;
+import com.microsoft.graph.security.models.IpEvidence;
+import com.microsoft.graph.security.models.KubernetesServiceAccountEvidence;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Pod Evidence.
+ */
+public class KubernetesPodEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Containers.
+ *
+ */
+ @SerializedName(value = "containers", alternate = {"Containers"})
+ @Expose
+ @Nullable
+ public java.util.List containers;
+
+ /**
+ * The Controller.
+ *
+ */
+ @SerializedName(value = "controller", alternate = {"Controller"})
+ @Expose
+ @Nullable
+ public KubernetesControllerEvidence controller;
+
+ /**
+ * The Ephemeral Containers.
+ *
+ */
+ @SerializedName(value = "ephemeralContainers", alternate = {"EphemeralContainers"})
+ @Expose
+ @Nullable
+ public java.util.List ephemeralContainers;
+
+ /**
+ * The Init Containers.
+ *
+ */
+ @SerializedName(value = "initContainers", alternate = {"InitContainers"})
+ @Expose
+ @Nullable
+ public java.util.List initContainers;
+
+ /**
+ * The Labels.
+ *
+ */
+ @SerializedName(value = "labels", alternate = {"Labels"})
+ @Expose
+ @Nullable
+ public Dictionary labels;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Namespace.
+ *
+ */
+ @SerializedName(value = "namespace", alternate = {"Namespace"})
+ @Expose
+ @Nullable
+ public KubernetesNamespaceEvidence namespace;
+
+ /**
+ * The Pod Ip.
+ *
+ */
+ @SerializedName(value = "podIp", alternate = {"PodIp"})
+ @Expose
+ @Nullable
+ public IpEvidence podIp;
+
+ /**
+ * The Service Account.
+ *
+ */
+ @SerializedName(value = "serviceAccount", alternate = {"ServiceAccount"})
+ @Expose
+ @Nullable
+ public KubernetesServiceAccountEvidence serviceAccount;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesSecretEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesSecretEvidence.java
new file mode 100644
index 00000000000..852b64e452e
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesSecretEvidence.java
@@ -0,0 +1,66 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.KubernetesNamespaceEvidence;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Secret Evidence.
+ */
+public class KubernetesSecretEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Namespace.
+ *
+ */
+ @SerializedName(value = "namespace", alternate = {"Namespace"})
+ @Expose
+ @Nullable
+ public KubernetesNamespaceEvidence namespace;
+
+ /**
+ * The Secret Type.
+ *
+ */
+ @SerializedName(value = "secretType", alternate = {"SecretType"})
+ @Expose
+ @Nullable
+ public String secretType;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceAccountEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceAccountEvidence.java
new file mode 100644
index 00000000000..125142d260f
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceAccountEvidence.java
@@ -0,0 +1,57 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.KubernetesNamespaceEvidence;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Service Account Evidence.
+ */
+public class KubernetesServiceAccountEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Namespace.
+ *
+ */
+ @SerializedName(value = "namespace", alternate = {"Namespace"})
+ @Expose
+ @Nullable
+ public KubernetesNamespaceEvidence namespace;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceEvidence.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceEvidence.java
new file mode 100644
index 00000000000..24d32d1beb2
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceEvidence.java
@@ -0,0 +1,116 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.http.BaseCollectionPage;
+import com.microsoft.graph.security.models.IpEvidence;
+import com.microsoft.graph.security.models.Dictionary;
+import com.microsoft.graph.security.models.KubernetesNamespaceEvidence;
+import com.microsoft.graph.security.models.KubernetesServicePort;
+import com.microsoft.graph.security.models.KubernetesServiceType;
+import com.microsoft.graph.security.models.AlertEvidence;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Service Evidence.
+ */
+public class KubernetesServiceEvidence extends AlertEvidence implements IJsonBackedObject {
+
+
+ /**
+ * The Cluster IP.
+ *
+ */
+ @SerializedName(value = "clusterIP", alternate = {"ClusterIP"})
+ @Expose
+ @Nullable
+ public IpEvidence clusterIP;
+
+ /**
+ * The External IPs.
+ *
+ */
+ @SerializedName(value = "externalIPs", alternate = {"ExternalIPs"})
+ @Expose
+ @Nullable
+ public java.util.List externalIPs;
+
+ /**
+ * The Labels.
+ *
+ */
+ @SerializedName(value = "labels", alternate = {"Labels"})
+ @Expose
+ @Nullable
+ public Dictionary labels;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Namespace.
+ *
+ */
+ @SerializedName(value = "namespace", alternate = {"Namespace"})
+ @Expose
+ @Nullable
+ public KubernetesNamespaceEvidence namespace;
+
+ /**
+ * The Selector.
+ *
+ */
+ @SerializedName(value = "selector", alternate = {"Selector"})
+ @Expose
+ @Nullable
+ public Dictionary selector;
+
+ /**
+ * The Service Ports.
+ *
+ */
+ @SerializedName(value = "servicePorts", alternate = {"ServicePorts"})
+ @Expose
+ @Nullable
+ public java.util.List servicePorts;
+
+ /**
+ * The Service Type.
+ *
+ */
+ @SerializedName(value = "serviceType", alternate = {"ServiceType"})
+ @Expose
+ @Nullable
+ public KubernetesServiceType serviceType;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServicePort.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServicePort.java
new file mode 100644
index 00000000000..0f66add8fad
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServicePort.java
@@ -0,0 +1,105 @@
+// Template Source: BaseEntity.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+import com.microsoft.graph.serializer.ISerializer;
+import com.microsoft.graph.serializer.IJsonBackedObject;
+import com.microsoft.graph.serializer.AdditionalDataManager;
+import java.util.EnumSet;
+import com.microsoft.graph.security.models.ContainerPortProtocol;
+
+
+import com.google.gson.JsonObject;
+import com.google.gson.annotations.SerializedName;
+import com.google.gson.annotations.Expose;
+import javax.annotation.Nullable;
+import javax.annotation.Nonnull;
+
+// **NOTE** This file was generated by a tool and any changes will be overwritten.
+
+/**
+ * The class for the Kubernetes Service Port.
+ */
+public class KubernetesServicePort implements IJsonBackedObject {
+
+ /** the OData type of the object as returned by the service */
+ @SerializedName("@odata.type")
+ @Expose
+ @Nullable
+ public String oDataType;
+
+ private transient AdditionalDataManager additionalDataManager = new AdditionalDataManager(this);
+
+ @Override
+ @Nonnull
+ public final AdditionalDataManager additionalDataManager() {
+ return additionalDataManager;
+ }
+
+ /**
+ * The App Protocol.
+ *
+ */
+ @SerializedName(value = "appProtocol", alternate = {"AppProtocol"})
+ @Expose
+ @Nullable
+ public String appProtocol;
+
+ /**
+ * The Name.
+ *
+ */
+ @SerializedName(value = "name", alternate = {"Name"})
+ @Expose
+ @Nullable
+ public String name;
+
+ /**
+ * The Node Port.
+ *
+ */
+ @SerializedName(value = "nodePort", alternate = {"NodePort"})
+ @Expose
+ @Nullable
+ public Integer nodePort;
+
+ /**
+ * The Port.
+ *
+ */
+ @SerializedName(value = "port", alternate = {"Port"})
+ @Expose
+ @Nullable
+ public Integer port;
+
+ /**
+ * The Protocol.
+ *
+ */
+ @SerializedName(value = "protocol", alternate = {"Protocol"})
+ @Expose
+ @Nullable
+ public ContainerPortProtocol protocol;
+
+ /**
+ * The Target Port.
+ *
+ */
+ @SerializedName(value = "targetPort", alternate = {"TargetPort"})
+ @Expose
+ @Nullable
+ public String targetPort;
+
+
+ /**
+ * Sets the raw JSON object
+ *
+ * @param serializer the serializer
+ * @param json the JSON object to set this object to
+ */
+ public void setRawObject(@Nonnull final ISerializer serializer, @Nonnull final JsonObject json) {
+
+ }
+}
diff --git a/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceType.java b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceType.java
new file mode 100644
index 00000000000..87959bd586e
--- /dev/null
+++ b/src/main/java/com/microsoft/graph/securitynamespace/models/KubernetesServiceType.java
@@ -0,0 +1,42 @@
+// Template Source: Enum.java.tt
+// ------------------------------------------------------------------------------
+// Copyright (c) Microsoft Corporation. All Rights Reserved. Licensed under the MIT License. See License in the project root for license information.
+// ------------------------------------------------------------------------------
+
+package com.microsoft.graph.security.models;
+
+
+/**
+ * The Enum Kubernetes Service Type.
+*/
+public enum KubernetesServiceType
+{
+ /**
+ * unknown
+ */
+ UNKNOWN,
+ /**
+ * cluster IP
+ */
+ CLUSTER_IP,
+ /**
+ * external Name
+ */
+ EXTERNAL_NAME,
+ /**
+ * node Port
+ */
+ NODE_PORT,
+ /**
+ * load Balancer
+ */
+ LOAD_BALANCER,
+ /**
+ * unknown Future Value
+ */
+ UNKNOWN_FUTURE_VALUE,
+ /**
+ * For KubernetesServiceType values that were not expected from the service
+ */
+ UNEXPECTED_VALUE
+}
diff --git a/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequestBuilder.java b/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequestBuilder.java
index 6aaea50669c..1968aac5ce6 100644
--- a/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequestBuilder.java
+++ b/src/main/java/com/microsoft/graph/requests/OrganizationalBrandingLocalizationCollectionRequestBuilder.java
@@ -7,6 +7,7 @@
import com.microsoft.graph.http.IRequestBuilder;
import com.microsoft.graph.core.ClientException;
+import com.microsoft.graph.models.OrganizationalBranding;
import com.microsoft.graph.models.OrganizationalBrandingLocalization;
import java.util.Arrays;
import java.util.EnumSet;
@@ -27,7 +28,7 @@
public class OrganizationalBrandingLocalizationCollectionRequestBuilder extends BaseCollectionRequestBuilder {
/**
* The request builder for this collection of OrganizationalBrandingLocalization
*
* @param requestUrl the request URL
* @param client the service client
@@ -27,7 +28,7 @@
public class OrganizationalBrandingLocalizationCollectionRequestBuilder extends BaseCollectionRequestBuilder {
/**
- * The request builder for this collection of OrganizationalBrandingLocalization
+ * The request builder for this collection of OrganizationalBranding
*
* @param requestUrl the request URL